#########################################################################################################
#
# Analysis for the paper: computer-based fear regulation during vret social anxiety
# 2018 TUDelft
# This script will generate output: "data_explore_computer_based_fear_regulation_during_vret_social_anxiety.txt" 
#
# Required datafiles:
# a. r_data_calibration.csv 
# b. r_data_main_session
# 
#########################################################################################################

# Adjust this to root folder that contain data files
setwd("D:/Surfdrive/PhD Research/#3/R/")

# Capture all the output to a file
sink("data_explore_computer_based_fear_regulation_during_vret_social_anxiety.txt")

# Print R version and operating system version used by this data analyses
sessionInfo()

# Dataset loading:
dataset_calibration <- read.csv("r_data_calibration.csv")
dataset_calibration$gender <- factor(dataset_calibration$gender, levels = c("m","f"), labels = c("male", "female"))
dataset_main <- read.csv("r_data_main_session.csv")

############################################### LIBRARIES ###############################################
# Libraries used for this analyses 

# if you not have one of this library, you can run this command to install your specific library
# install.packages("ez", dependencies = TRUE)
library(reshape2)
library(car)

# Functions:
boxplot_cal <- function(data1, data2, data3, data4, text) {
  boxplot(data1, data2, data3, data4, 
          main = text,
          names = c("1 minutes", "2 minutes", "3 minutes", "4 minutes"))
}

boxplot_main <- function(data1, data2, data3, data4, text) {
  boxplot(data1, data2, data3, data4,
          main = text,
          names = c("4 minutes", "8 minutes", "12 minutes", "16 minutes"))
}

##########################################################################################################

# Data explorer

cat("\nBoxplot: Calibration Session generated...\n")
#
# SUD Relax condition
cat("Boxplot - SUD Relax condition generated...")
boxplot_cal(dataset_calibration$sud_relax_1, dataset_calibration$sud_relax_2, dataset_calibration$sud_relax_3, dataset_calibration$sud_relax_4,
            "SUD - relax condition")
# SUD Stress condition
boxplot_cal(dataset_calibration$sud_stress_1, dataset_calibration$sud_stress_2, dataset_calibration$sud_stress_3, dataset_calibration$sud_stress_4,
            "SUD - stress condition")
# Heart Rate relax condtion
boxplot_cal(dataset_calibration$hr_relax_1, dataset_calibration$hr_relax_2, dataset_calibration$hr_relax_3, dataset_calibration$hr_relax_4,
            "Heart rate - relax condition")
# Heart rate stress condition
boxplot_cal(dataset_calibration$hr_stress_1, dataset_calibration$hr_stress_2, dataset_calibration$hr_stress_3, dataset_calibration$hr_stress_4,
            "Heart rate - stress condition")

cat("\nBoxplot: Main Session generated...\n\n")
# 
# SUD - static condition
boxplot_main(dataset_main$sud_static_1, dataset_main$sud_static_2, dataset_main$sud_static_3, dataset_main$sud_static_4,
             "SUD - static condition")
# SUD - dynamic condition
boxplot_main(dataset_main$sud_auto_1, dataset_main$sud_auto_2, dataset_main$sud_auto_3, dataset_main$sud_auto_4,
             "SUD - dynamic condition")

# Heart rate - static condition
boxplot_main(dataset_main$hr_static_1, dataset_main$hr_static_2, dataset_main$hr_static_3, dataset_main$hr_static_4,
             "Heart rate - static condition")
# Heart rate - dynamic condition
boxplot_main(dataset_main$hr_auto_1, dataset_main$hr_auto_2, dataset_main$hr_auto_3, dataset_main$hr_auto_4,
             "Heart rate - dynamic condition")

# Heart rate variability - static condition
boxplot_main(dataset_main$hrv_static_1, dataset_main$hrv_static_2, dataset_main$hrv_static_3, dataset_main$hrv_static_4,
             "Heart rate variability - static condition ")
# Heart rate variability - dynamic condition
boxplot_main(dataset_main$hrv_auto_1, dataset_main$hrv_auto_2, dataset_main$hrv_auto_3, dataset_main$hrv_auto_4,
             "Heart rate variability - dynamic condition")

# Length of speak - static condition
boxplot_main(dataset_main$speak_static_1, dataset_main$speak_static_2, dataset_main$speak_static_3, dataset_main$speak_static_4,
             "Length of speak - static condition")
# Length of speak - dynamic condition
boxplot_main(dataset_main$speak_auto_1, dataset_main$speak_auto_2, dataset_main$speak_auto_3, dataset_main$speak_auto_4,
             "Length of speak - dynamic condition")

#
# Normality test:
cat("\n=== Normality test ===\n")
# 
# Calibration session
cat("\nCalibration session\n\n")
# SUD - relax condition
cat("Normality test: SUD score in relax condition, 1st minutes\n")
shapiro.test(dataset_calibration$sud_relax_1)
cat("Normality test: SUD score in relax condition, 2nd minutes\n")
shapiro.test(dataset_calibration$sud_relax_2)
cat("Normality test: SUD score in relax condition, 3th minutes\n")
shapiro.test(dataset_calibration$sud_relax_3)
cat("Normality test: SUD score in relax condition, 4th minutes\n")
shapiro.test(dataset_calibration$sud_relax_4)

# SUD - stress condition
cat("Normality test: SUD score in stress condition, 1st minutes\n")
shapiro.test(dataset_calibration$sud_stress_1)
cat("Normality test: SUD score in stress condition, 2nd minutes\n")
shapiro.test(dataset_calibration$sud_stress_2)
cat("Normality test: SUD score in stress condition, 3th minutes\n")
shapiro.test(dataset_calibration$sud_stress_3)
cat("Normality test: SUD score in stress condition, 4th minutes\n")
shapiro.test(dataset_calibration$sud_stress_4)

# Heart rate - relax condition
cat("Normality test: heart rate in relax condition, 1st minutes\n")
shapiro.test(dataset_calibration$hr_relax_1)
cat("Normality test: heart rate in relax condition, 2nd minutes\n")
shapiro.test(dataset_calibration$hr_relax_2)
cat("Normality test: heart rate in relax condition, 3th minutes\n")
shapiro.test(dataset_calibration$hr_relax_3)
cat("Normality test: heart rate in relax condition, 4th minutes\n")
shapiro.test(dataset_calibration$hr_relax_4)

# Heart rate - stress condition
cat("Normality test: heart rate in stress condition, 1st minutes\n")
shapiro.test(dataset_calibration$hr_stress_1)
cat("Normality test: heart rate in stress condition, 2nd minutes\n")
shapiro.test(dataset_calibration$hr_stress_2)
cat("Normality test: heart rate in stress condition, 3th minutes\n")
shapiro.test(dataset_calibration$hr_stress_3)
cat("Normality test: heart rate in stress condition, 4th minutes\n")
shapiro.test(dataset_calibration$hr_stress_4)

# Main session
cat("\n== Main session ===\n\n")

# SUD - static condition
cat("SUD score - static condition\n")
cat("Normality test: SUD score in static condition, 4 minutes\n")
shapiro.test(dataset_main$sud_static_1)
cat("Normality test: SUD score in static condition, 8 minutes\n")
shapiro.test(dataset_main$sud_static_2)
cat("Normality test: SUD score in static condition, 12 minutes\n")
shapiro.test(dataset_main$sud_static_3)
cat("Normality test: SUD score in static condition, 16 minutes\n")
shapiro.test(dataset_main$sud_static_4)

# SUD - dynamic condition
cat("SUD score - dynamic condition\n")
cat("Normality test: SUD score in dynamic condition, 4 minutes\n")
shapiro.test(dataset_main$sud_auto_1)
cat("Normality test: SUD score in dynamic condition, 8 minutes\n")
shapiro.test(dataset_main$sud_auto_2)
cat("Normality test: SUD score in dynamic condition, 12 minutes\n")
shapiro.test(dataset_main$sud_auto_3)
cat("Normality test: SUD score in dynamic condition, 16 minutes\n")
shapiro.test(dataset_main$sud_auto_4)

# Heart rate - static condition
cat("Heart rate - static condition\n")
cat("Normality test: Heart rate in static condition, 4 minutes\n")
shapiro.test(dataset_main$hr_static_1)
cat("Normality test: Heart rate in static condition, 8 minutes\n")
shapiro.test(dataset_main$hr_static_2)
cat("Normality test: Heart rate in static condition, 12 minutes\n")
shapiro.test(dataset_main$hr_static_3)
cat("Normality test: Heart rate in static condition, 16 minutes\n")
shapiro.test(dataset_main$hr_static_4)

# Heart rate - dynamic condition
cat("Heart rate - dynamic condition\n")
cat("Normality test: Heart rate in dynamic condition, 4 minutes\n")
shapiro.test(dataset_main$hr_auto_1)
cat("Normality test: Heart rate in dynamic condition, 8 minutes\n")
shapiro.test(dataset_main$hr_auto_2)
cat("Normality test: Heart rate in dynamic condition, 12 minutes\n")
shapiro.test(dataset_main$hr_auto_3)
cat("Normality test: Heart rate in dynamic condition, 16 minutes\n")
shapiro.test(dataset_main$hr_auto_4)

# Heart rate variability - static condition
cat("Heart rate - static condition\n")
cat("Normality test: Heart rate variability in static condition, 4 minutes\n")
shapiro.test(dataset_main$hrv_static_1)
cat("Normality test: Heart rate variability in static condition, 8 minutes\n")
shapiro.test(dataset_main$hrv_static_2)
cat("Normality test: Heart rate variability in static condition, 12 minutes\n")
shapiro.test(dataset_main$hrv_static_3)
cat("Normality test: Heart rate variability in static condition, 16 minutes\n")
shapiro.test(dataset_main$hrv_static_4)

# Heart rate variability - dynamic condition
cat("Heart rate variability - dynamic condition\n")
cat("Normality test: Heart rate variability in dynamic condition, 4 minutes\n")
shapiro.test(dataset_main$hrv_auto_1)
cat("Normality test: Heart rate variability in dynamic condition, 8 minutes\n")
shapiro.test(dataset_main$hrv_auto_2)
cat("Normality test: Heart rate variability in dynamic condition, 12 minutes\n")
shapiro.test(dataset_main$hrv_auto_3)
cat("Normality test: Heart rate variability in dynamic condition, 16 minutes\n")
shapiro.test(dataset_main$hrv_auto_4)

# Lenght of speak - static condition
cat("Lenght of speak - static condition\n")
cat("Normality test: Lenght of speak in static condition, 4 minutes\n")
shapiro.test(dataset_main$speak_static_1)
cat("Normality test: Lenght of speak in static condition, 8 minutes\n")
shapiro.test(dataset_main$speak_static_2)
cat("Normality test: Lenght of speak in static condition, 12 minutes\n")
shapiro.test(dataset_main$speak_static_3)
cat("Normality test: Lenght of speak in static condition, 16 minutes\n")
shapiro.test(dataset_main$speak_static_4)

# Lenght of speak - dynamic condition
cat("Lenght of speak - dynamic condition\n")
cat("Normality test: Lenght of speak in dynamic condition, 4 minutes\n")
shapiro.test(dataset_main$speak_auto_1)
cat("Normality test: Lenght of speak in dynamic condition, 8 minutes\n")
shapiro.test(dataset_main$speak_auto_2)
cat("Normality test: Lenght of speak in dynamic condition, 12 minutes\n")
shapiro.test(dataset_main$speak_auto_3)
cat("Normality test: Lenght of speak in dynamic condition, 16 minutes\n")
shapiro.test(dataset_main$speak_auto_4)


######### stop redireting output.
sink()

cat("\n\nOutput of this R script file: data_explore_computer_based_fear_regulation_during_vret_social_anxiety.txt")








