#########################################################################################################
#
# Analysis for the paper: computer-based fear regulation during vret social anxiety
# 2018 TUDelft
# This script will generate output: "data_preparation_computer_based_fear_regulation_during_vret_social_anxiety.txt" 
#
# Required datafiles:
# a. r_data_calibration.csv 
# b. r_data_questionnaires.csv
# c. r_data_main_session
# 
#########################################################################################################

# Adjust this to root folder that contain data files
setwd("D:/Surfdrive/PhD Research/#3/R/")

# Capture all the output to a file
sink("data_preparation_computer_based_fear_regulation_during_vret_social_anxiety.txt")

# Print R version and operating system version used by this data analyses
sessionInfo()

############################################### LIBRARIES ###############################################
# Libraries used for this analyses 

# if you not have one of this library, you can run this command to install your specific library
# install.packages("ez", dependencies = TRUE)
library(reshape2)
library(RSQLite)

################################################ DATA ####################################################

# File: r_data_calibration.csv
# 
# 01. Pid = participants ID number
# 02. age = age of participants
# 03. gender = gender of  participants, coded: male = 0, female = 1
# 04. sud_relax_1 = SUD score in the relax condition at the 1st stage (the 1st 4 minutes measurements)
# 05. sud_relax_2 = SUD score in the relax condition at the 2nd stage (the 2nd 4 minutes measurements)
# 06. sud_relax_3 = SUD score in the relax condition at the 3th stage (the 3th 4 minutes measurements)
# 07. sud_relax_4 = SUD score in the relax condition at the 4th stage (the 4th 4 minutes measurements)
# 08. sud_stress_1 = SUD score in the stress condition at the 1st stage (the 1st 4 minutes measurements)
# 09. sud_stress_2 = SUD score in the stress condition at the 2nd stage (the 2nd 4 minutes measurements)
# 10. sud_stress_3 = SUD score in the stress condition at the 3th stage (the 3th 4 minutes measurements)
# 11. sud_stress_4 = SUD score in the stress condition at the 4th stage (the 4th 4 minutes measurements)
# 12. hr_relax_1 = hr measurements in the relax condition at the 1st stage (the 1st 4 minutes measurements)
# 13. hr_relax_2 = hr measurements in the relax condition at the 2nd stage (the 2nd 4 minutes measurements)
# 14. hr_relax_3 = hr measurements in the relax condition at the 3th stage (the 3th 4 minutes measurements)
# 15. hr_relax_4 = hr measurements in the relax condition at the 4th stage (the 4th 4 minutes measurements)
# 16. hr_stress_1 = hr measurements in the stress condition at the 1st stage (the 1st 4 minutes measurements)
# 17. hr_stress_2 = hr measurements in the stress condition at the 2nd stage (the 2nd 4 minutes measurements)
# 18. hr_stress_3 = hr measurements in the stress condition at the 3th stage (the 3th 4 minutes measurements)
# 19. hr_stress_4 = hr measurements in the stress condition at the 4th stage (the 4th 4 minutes measurements)

# File: r_data_questionnaires.csv
#
# 01. pid: participants ID number
# 02. iaq_static_1: interview and attitude questionnaires question 1 in the static condition
# 03. iaq_static_2: interview and attitude questionnaires question 2 in the static condition
# 04. iaq_static_3: interview and attitude questionnaires question 3 in the static condition
# 05. iaq_static_4: interview and attitude questionnaires question 4 in the static condition
# 06. iaq_static_5: interview and attitude questionnaires question 5 in the static condition
# 07. iaq_static_6: interview and attitude questionnaires question 6 in the static condition
# 08. iaq_auto_1: interview and attitude questionnaires question 1 in the automatic/ dynamic condition
# 09. iaq_auto_2: interview and attitude questionnaires question 2 in the automatic/ dynamic condition
# 10. iaq_auto_3: interview and attitude questionnaires question 3 in the automatic/ dynamic condition
# 11. iaq_auto_4: interview and attitude questionnaires question 4 in the automatic/ dynamic condition
# 12. iaq_auto_5: interview and attitude questionnaires question 5 in the automatic/ dynamic condition
# 13. iaq_auto_6: interview and attitude questionnaires question 6 in the automatic/ dynamic condition
# 14. sam_static_p_v: SAM questionnaires (Valence dimension) measuring participant's emotion in the static condition
# 15. sam_static_p_a: SAM questionnaires (Arousal dimension) measuring participant's emotion in the static condition
# 16. sam_static_p_d: SAM questionnaires (Dominance dimension) measuring participant's emotion in the static condition
# 17. sam_static_a_v: SAM questionnaires (Valence dimension) measuring avatar's emotion in the static condition
# 18. sam_static_a_a: SAM questionnaires (Arousal dimension) measuring avatar's emotion in the static condition
# 19. sam_static_a_d: SAM questionnaires (Dominance dimension) measuring avatar's emotion in the static condition
# 20. sam_auto_p_v: SAM questionnaires (Valence dimension) measuring participant's emotion in the automatic/ dynamic condition
# 21. sam_auto_p_a: SAM questionnaires (Arousal dimension) measuring participant's emotion in the automatic/ dynamic condition
# 22. sam_auto_p_d: SAM questionnaires (Dominance dimension) measuring participant's emotion in the automatic/ dynamic condition
# 23. sam_auto_a_v: SAM questionnaires (Valence dimension) measuring avatar's emotion in the automatic/ dynamic condition
# 24. sam_auto_a_a: SAM questionnaires (Arousal dimension) measuring avatar's emotion in the automatic/ dynamic condition
# 25. sam_auto_a_d: SAM questionnaires (Dominance dimension) measuring avatar's emotion in the automatic/ dynamic condition
# 26. deq_static: dialogue experience questionnaires questionnares in the static condition
# 27. deq_auto: dialogue experience questionnaires questionnares in the automatic/ dynamic condition
# 28. sias: Social Interaction Anxiety Scale (SIAS) questionnares's result
# 29. ipq_sp1: IPQ question number 1 (sense of being there) in condition 1
# 30. ipq_sp2: IPQ question number 2 (sense of VE surrounds me) in condition 1
# 31. ipq_inv1: IPQ question number 3 (senses of only pictures) in condition 1
# 32. ipq_sp4: IPQ question number 4 (not sense of being in virtual space) in condition 1
# 33. ipq_sp5: IPQ question number 5 (sense of acting in virtual environtment/ VE) in condition 1
# 34. ipq_inv2: IPQ question number 6 (sense of being present in VE) in condition 1
# 35. ipq_inv3: IPQ question number 7 (awareness of real environtment) in condition 1
# 36. ipq_inv4: IPQ question number 8 (not aware of real environtment) in condition 1
# 37. ipq_real4: IPQ question number 9 (no attention to real environtment) in condition 1
# 38. ipq_g1: IPQ question number 10 (attention captivated by VE) in condition 1
# 39. ipq_sp3: IPQ question number 11 (VE real is not real/ real) in condition 1
# 40. ipq_real1: IPQ question number 12 (experience similar to real environtment) in condition 1
# 41. ipq_real2: IPQ question number 13 (VE is imagined/ real) in condition 1
# 42. ipq_real3: IPQ question number 14 (VE seemed more realistic than the real world) in condition 1
# 43. sias_1: SIAS question number 1 (I get nervous if I have to speak with someone in authority)
# 44. sias_2: SIAS question number 1 (I have difficulty making eye contact with others)
# 45. sias_3: SIAS question number 1 (I become tense if I have to talk about myself or my feelings)
# 46. sias_4: SIAS question number 1 ( I find it difficult to mix comfortably with the people I work with)
# 47. sias_5: SIAS question number 1 (I find it easy to make friends my own age)
# 48. sias_6: SIAS question number 1 (I tense up if I meet an acquaintance in the street)
# 49. sias_7: SIAS question number 1 (When mixing socially, I am uncomfortable)
# 50. sias_8: SIAS question number 1 (I feel tense if I am alone with just one other person)
# 51. sias_9: SIAS question number 1 (I am at ease meeting people at parties, etc)
# 52. sias_10: SIAS question number 1 (I have difficulty talking with other people)
# 53. sias_11: SIAS question number 1 (I find it easy to think of things to talk about)
# 54. sias_12: SIAS question number 1 (I worry about expressing myself in case I appear awkward)
# 55. sias_13: SIAS question number 1 (I find it difficult to disagree with another's point of view)
# 56. sias_14: SIAS question number 1 (I have difficulty talking to attractive persons of the opposite sex)
# 57. sias_15: SIAS question number 1 (I find myself worrying that I won't know what to say in social situations)
# 58. sias_16: SIAS question number 1 (I am nervous mixing with people I don't know well)
# 59. sias_17: SIAS question number 1 (I feel I'll say something embarrassing when talking)
# 60. sias_18: SIAS question number 1 (When mixing in a group, I find myself worrying I will be ignored)
# 61. sias_19: SIAS question number 1 (I am tense mixing in a group)
# 62. sias_20: SIAS question number 1 (I am unsure whether to greet someone I know only slightly)
# 63. deq_static_1: Dialogue Expereince Questionniare - SPEED (in static condition)
# 64. deq_static_2: Dialogue Expereince Questionniare - INTERACTION (in static condition)
# 65. deq_static_3: Dialogue Expereince Questionniare - CORRECT LOCALLY (in static condition)
# 66. deq_static_4: Dialogue Expereince Questionniare - CORRECT GLOBALLY (in static condition)
# 67. deq_static_5: Dialogue Expereince Questionniare - INVOLVEMENT (in static condition)
# 68. deq_static_6: Dialogue Expereince Questionniare - SATISFACTION (in static condition)
# 69. deq_static_7: Dialogue Expereince Questionniare - REALITY (in static condition)
# 70. deq_auto_1: Dialogue Expereince Questionniare - SPEED (in dynamic condition)
# 71. deq_auto_2: Dialogue Expereince Questionniare - INTERACTION (in dynamic condition)
# 72. deq_auto_3: Dialogue Expereince Questionniare - CORRECT LOCALLY (in dynamic condition)
# 73. deq_auto_4: Dialogue Expereince Questionniare - CORRECT GLOBALLY (in dynamic condition)
# 74. deq_auto_5: Dialogue Expereince Questionniare - INVOLVEMENT (in dynamic condition)
# 75. deq_auto_6: Dialogue Expereince Questionniare - SATISFACTION (in dynamic condition)
# 76. deq_auto_7: Dialogue Expereince Questionniare - REALITY (in dynamic condition)

# File: r_ipq_online.sav
# this IPQ data is downloaded from http://igroup.org/pq/ipq/download.php, we took the most relevants items only to be compared with our experiment's results
#
#1.   res         - not used
#2.   study       - not used
#3.   lang        - not used
#4.   version     - not used
#5.   nofcase     - not used
#6.   video       - not used
#7.   audio       - not used
#8.   perspect    - not used
#9.   dura        - not used
#10.  and_r       - not used
#11.  and_s       - not used
#12.  app         - not used
#13.  age         - not used
#14.  gender      - not used
#15.  type        - not used
#16.  g1          - sense of being there - In the computer generated world I had a sense of "being there"
#17.  sp1         - sense of VE behind - Somehow I felt that the virtual world surrounded me.
#18.  sp2         - only pictures - I felt like I was just perceiving pictures.   
#19.  sp3         - not sense of being in v. space - I did not feel present in the virtual space.
#20.  sp4         - sense of acting in VE - I had a sense of acting in the virtual space, rather than operating something from outside.
#21.  sp5         - sense of being present in VE - I felt present in the virtual space.
#22.  inv1        - awareness of real env. - How aware were you of the real world surrounding while navigating in the virtual world? (i.e. sounds, room temperature, other people, etc.)?
#23.  inv2        - not aware of real env. - I was not aware of my real environment.
#24.  inv3        - no attention to real env. - I still paid attention to the real environment.
#25.  inv4        - attention captivated by VE - I was completely captivated by the virtual world.
#26.  real1       - VE real (real/not real) - How real did the virtual world seem to you?
#27.  real2       - experience similar to real env. - How much did your experience in the virtual environment seem consistent with your real world experience ?
#28.  real3       - VE real (imagined/real) - How real did the virtual world seem to you?
#29.  real4       - VE wirklich - The virtual world seemed more realistic than the real world.
#
# Note SP2, INV3, and REAL1 are reversed, eg. (-1 * sp2 + 6)

# File: r_data_main_session.csv

# 01. pid = participants ID
# 02. sud_static_1 = participants' subjective unit of discomfort (SUD) score in the static condition at 1st stage of measurement (4 minutes)
# 03. sud_static_2 = participants' subjective unit of discomfort (SUD) score in the static condition at 2nd stage of measurement (4 minutes)
# 04. sud_static_3 = participants' subjective unit of discomfort (SUD) score in the static condition at 3rd stage of measurement (4 minutes)
# 05. sud_static_4 = participants' subjective unit of discomfort (SUD) score in the static condition at 4th stage of measurement (4 minutes)
# 06. sud_auto_1 = participants' subjective unit of discomfort (SUD) score in the automatic/ dynamic condition at 1st stage of measurement (4 minutes)
# 07. sud_auto_2 = participants' subjective unit of discomfort (SUD) score in the automatic/ dynamic condition at 2nd stage of measurement (4 minutes)
# 08. sud_auto_3 = participants' subjective unit of discomfort (SUD) score in the automatic/ dynamic condition at 3rd stage of measurement (4 minutes)
# 09. sud_auto_4 = participants' subjective unit of discomfort (SUD) score in the automatic/ dynamic condition at 4th stage of measurement (4 minutes)
# 10. hr_static_1 = participants' heart rate measurement result in the static condition at 1st stage of measurement (4 minutes)
# 11. hr_static_2 = participants' heart rate measurement result in the static condition at 2nd stage of measurement (4 minutes)
# 12. hr_static_3 = participants' heart rate measurement result in the static condition at 3rd stage of measurement (4 minutes)
# 13. hr_static_4 = participants' heart rate measurement result in the static condition at 4th stage of measurement (4 minutes)
# 14. hr_auto_1 = participants' heart rate measurement result in the automatic/ dynamic condition at 1st stage of measurement (4 minutes)
# 15. hr_auto_2 = participants' heart rate measurement result in the automatic/ dynamic condition at 2nd stage of measurement (4 minutes)
# 16. hr_auto_3 = participants' heart rate measurement result in the automatic/ dynamic condition at 3rd stage of measurement (4 minutes)
# 17. hr_auto_4 = participants' heart rate measurement result in the automatic/ dynamic condition at 4th stage of measurement (4 minutes)
# 18. speak_static_1 = participants' length of speak measurement result in the static condition at 1st stage of measurement (4 minutes)
# 19. speak_static_2 = participants' length of speak measurement result in the static condition at 2nd stage of measurement (4 minutes)
# 20. speak_static_3 = participants' length of speak measurement result in the static condition at 3rd stage of measurement (4 minutes)
# 21. speak_static_4 = participants' length of speak measurement result in the static condition at 4th stage of measurement (4 minutes)
# 22. speak_auto_1 = participants' length of speak measurement result in the automatic/ dynamic condition at 1st stage of measurement (4 minutes)
# 23. speak_auto_2 = participants' length of speak measurement result in the automatic/ dynamic condition at 2nd stage of measurement (4 minutes)
# 24. speak_auto_3 = participants' length of speak measurement result in the automatic/ dynamic condition at 3rd stage of measurement (4 minutes)
# 25. speak_auto_4 = participants' length of speak measurement result in the automatic/ dynamic condition at 4th stage of measurement (4 minutes)
# 26. hrv_static_1 = participants' heart rate variability measurement result in the static condition at 1st stage of measurement (4 minutes)
# 27. hrv_static_2 = participants' heart rate variability measurement result in the static condition at 2nd stage of measurement (4 minutes)
# 28. hrv_static_3 = participants' heart rate variability measurement result in the static condition at 3rd stage of measurement (4 minutes)
# 29. hrv_static_4 = participants' heart rate variability measurement result in the static condition at 4th stage of measurement (4 minutes)
# 30. hrv_auto_1 = participants' heart rate variability measurement result in the automatic/ dynamic condition at 1st stage of measurement (4 minutes)
# 31. hrv_auto_2 = participants' heart rate variability measurement result in the automatic/ dynamic condition at 2nd stage of measurement (4 minutes)
# 32. hrv_auto_3 = participants' heart rate variability measurement result in the automatic/ dynamic condition at 3rd stage of measurement (4 minutes)
# 33. hrv_auto_4 = participants' heart rate variability measurement result in the automatic/ dynamic condition at 4th stage of measurement (4 minutes)

############################################### FUNCTIONS ###############################################
# List available table in the database
db_view_table <- function(database) {
  filename <- database
  sqlite.driver <- dbDriver("SQLite")
  db <- dbConnect(sqlite.driver, dbname = filename)
  ## list table query
  ListTables <- dbListTables(db)
  dbDisconnect(db)
  cat("Your tables: ", ListTables)
}

# Database/ SQL operation
read_db <- function(database, table){
  filename <- database
  sqlite.driver <- dbDriver("SQLite")
  db <- dbConnect(sqlite.driver, dbname = filename)
  ## table query
  dbListTables(db)
  mytable <- dbReadTable(db, table)
  dbDisconnect(db)
  return (mytable)
}

###########################################################################################################

# Dataset check preparation:
cat("Dataset checks preparation...\n")
dataset_calibration <- read.csv("r_data_calibration.csv")
dataset_calibration$gender <- factor(dataset_calibration$gender, levels = c("m","f"), labels = c("male", "female"))
dataset_questionnaire <- read.csv("r_data_questionnaires.csv")
dataset_main <- read.csv("r_data_main_session.csv")
cat("Dataset checks preparation completed.\n")

######### stop redireting output.
sink()

cat("\n\nOutput of this R script file: data_preparation_computer_based_fear_regulation_during_vret_social_anxiety.txt") 





